Package: threejs
Type: Package
Title: Interactive 3D Scatter Plots, Networks and Globes
Description: Create interactive 3D scatter plots, network plots, and
    globes using the 'three.js' visualization library (<https://threejs.org>).
Version: 0.3.3
Date: 2020-01-19
Authors@R: c(
    person("B. W.", "Lewis", role=c("aut","cre","cph"), email="blewis@illposed.net"),
    person(given="Three.js authors", role="cph", comment="three.js library"),
    person(given="jQuery Foundation", role="cph", comment="jQuery library"),
    person("Alexey", "Stukalov", role=("ctb"), email="astukalov@gmail.com"),
    person("Yihui","Xie", role=("ctb"), email="xie@yihui.name"),
    person("Andreas", "Briese", role=("ctb"), email="ab@edutoolbox.de"),
    person("B.", "Thieurmel", role=("ctb"), email="bthieurmel@gmail.com")
    )
URL: https://bwlewis.github.io/rthreejs
BugReports: https://github.com/bwlewis/rthreejs/issues
License: MIT + file LICENSE
Depends: R (>= 3.0.0), igraph (>= 1.0.0)
Imports: htmlwidgets (>= 0.3.2), base64enc, crosstalk, methods, stats
Suggests: maps
Enhances: knitr, shiny
Encoding: UTF-8
RoxygenNote: 7.0.2
Author: B. W. Lewis [aut, cre, cph],
  Three.js authors [cph] (three.js library),
  jQuery Foundation [cph] (jQuery library),
  Alexey Stukalov [ctb],
  Yihui Xie [ctb],
  Andreas Briese [ctb],
  B. Thieurmel [ctb]
Maintainer: B. W. Lewis <blewis@illposed.net>
Built: R 4.4.0; ; 2024-04-27 22:52:28 UTC; unix
